@@ -227,7 +227,7 @@ class CortxJupyter(ContentsManager):
             return (yield _delete_checkpoint(self._context(), checkpoint_id, path))
 
     def _context(self):
-        return Context(s
+        return Context(
             logger=self.log,
             region=self.aws_region,
             s3_bucket=self.aws_s3_bucket,
